Linux bluetooth development
 help / color / mirror / Atom feed
From: johan.hedberg@gmail.com
To: linux-bluetooth@vger.kernel.org
Subject: [PATCH 09/15] Bluetooth: Fix hdev->own_addr_type value when privacy is set
Date: Sat, 22 Feb 2014 19:06:39 +0200	[thread overview]
Message-ID: <1393088805-28658-10-git-send-email-johan.hedberg@gmail.com> (raw)
In-Reply-To: <1393088805-28658-1-git-send-email-johan.hedberg@gmail.com>

From: Johan Hedberg <johan.hedberg@intel.com>

When powering on the controller and deciding what value to set to
hdev->own_address_time take also into account the HCI_PRIVACY flag (in
which case random own address should be used).

Signed-off-by: Johan Hedberg <johan.hedberg@intel.com>
---
 net/bluetooth/hci_core.c | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/net/bluetooth/hci_core.c b/net/bluetooth/hci_core.c
index 964aa8deb009..753a73ba6764 100644
--- a/net/bluetooth/hci_core.c
+++ b/net/bluetooth/hci_core.c
@@ -1477,14 +1477,16 @@ static void hci_init3_req(struct hci_request *req, unsigned long opt)
 
 	if (lmp_le_capable(hdev)) {
 		/* If the controller has a public BD_ADDR, then by default
 		 * use that one. If this is a LE only controller without
 		 * a public address, default to the random address.
 		 *
 		 * For debugging purposes it is possible to force
 		 * controllers with a public address to use the
 		 * random address instead.
 		 */
-		if (test_bit(HCI_FORCE_STATIC_ADDR, &hdev->dev_flags) ||
+		if (test_bit(HCI_PRIVACY, &hdev->dev_flags) ||
+		    test_bit(HCI_FORCE_STATIC_ADDR, &hdev->dev_flags) ||
 		    !bacmp(&hdev->bdaddr, BDADDR_ANY))
 			hdev->own_addr_type = ADDR_LE_DEV_RANDOM;
 		else
@@ -1477,14 +1477,16 @@ static void hci_init3_req(struct hci_request *req, unsigned long opt)
 	if (lmp_le_capable(hdev)) {
 		/* If the controller has a public BD_ADDR, then by default
-		 * use that one. If this is a LE only controller without
-		 * a public address, default to the random address.
+		 * use that one, unless Privacy is enabled. If this is a LE
+		 * only controller without a public address, default to
+		 * the random address.
 		 *
 		 * For debugging purposes it is possible to force
-- 
1.8.5.3


  parent reply	other threads:[~2014-02-22 17:06 UTC|newest]

Thread overview: 29+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2014-02-22 17:06 [PATCH 00/15] Bluetooth: LE Privacy support johan.hedberg
2014-02-22 17:06 ` [PATCH 01/15] Bluetooth: Add helper variables to smp_distribute_keys() johan.hedberg
2014-02-22 17:06 ` [PATCH 02/15] Bluetooth: Add initial code for distributing local IRK johan.hedberg
2014-02-22 17:06 ` [PATCH 03/15] Bluetooth: Move enable/disable_advertising higher up in mgmt.c johan.hedberg
2014-02-22 17:06 ` [PATCH 04/15] Bluetooth: Add mgmt defines for privacy johan.hedberg
2014-02-22 17:06 ` [PATCH 05/15] Bluetooth: Add Privacy lag to mgmt supported/current settings johan.hedberg
2014-02-22 17:06 ` [PATCH 06/15] Bluetooth: Add skeleton for Set Privacy command johan.hedberg
2014-02-22 17:56   ` Marcel Holtmann
2014-02-22 17:06 ` [PATCH 07/15] Bluetooth: Add SMP function for generating RPAs johan.hedberg
2014-02-22 18:00   ` Marcel Holtmann
2014-02-22 17:06 ` [PATCH 08/15] Bluetooth: Don't write static address when privacy is enabled johan.hedberg
2014-02-22 18:03   ` Marcel Holtmann
2014-02-22 17:06 ` johan.hedberg [this message]
2014-02-22 18:06   ` [PATCH 09/15] Bluetooth: Fix hdev->own_addr_type value when privacy is set Marcel Holtmann
2014-02-22 17:06 ` [PATCH 10/15] Bluetooth: Add mechanism for updating the local RPA johan.hedberg
2014-02-22 18:10   ` Marcel Holtmann
2014-02-22 18:37     ` Johan Hedberg
2014-02-22 18:40       ` Marcel Holtmann
2014-02-22 17:06 ` [PATCH 11/15] Bluetooth: Update local RPA if necessary when connecting LE johan.hedberg
2014-02-22 18:12   ` Marcel Holtmann
2014-02-22 17:06 ` [PATCH 12/15] Bluetooth: Update local RPA if necessary before enabling advertising johan.hedberg
2014-02-22 18:17   ` Marcel Holtmann
2014-02-22 17:06 ` [PATCH 13/15] Bluetooth: Update local RPA if necessary before starting LE scan johan.hedberg
2014-02-22 18:13   ` Marcel Holtmann
2014-02-22 17:06 ` [PATCH 14/15] Bluetooth: Add debugfs entry for RPA regeneration timeout johan.hedberg
2014-02-22 18:15   ` Marcel Holtmann
2014-02-22 17:06 ` [PATCH 15/15] Bluetooth: Add full support for updating privacy state johan.hedberg
2014-02-22 18:16   ` Marcel Holtmann
2014-02-22 18:00 ` [PATCH 00/15] Bluetooth: LE Privacy support Marcel Holtmann

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1393088805-28658-10-git-send-email-johan.hedberg@gmail.com \
    --to=johan.hedberg@gmail.com \
    --cc=linux-bluetooth@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox